Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(356)

Unified Diff: webkit/plugins/ppapi/ppapi_plugin_instance.h

Issue 10912060: Allow the NaCl IPC proxy to support multiple instances. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/plugins/ppapi/ppapi_plugin_instance.h
===================================================================
--- webkit/plugins/ppapi/ppapi_plugin_instance.h (revision 154244)
+++ webkit/plugins/ppapi/ppapi_plugin_instance.h (working copy)
@@ -467,7 +467,7 @@
// proxy and re-sends DidCreate, DidChangeView, and HandleDocumentLoad (if
// necessary).
// This is for use with the NaCl proxy.
- bool ResetAsProxied();
+ bool ResetAsProxied(scoped_refptr<PluginModule> module);
private:
// Implements PPB_Gamepad_API. This is just to avoid having an excessive
@@ -571,10 +571,11 @@
PluginDelegate* delegate_;
scoped_refptr<PluginModule> module_;
scoped_ptr< ::ppapi::PPP_Instance_Combined> instance_interface_;
- // If this is the NaCl plugin, store its instance interface so we can shut
- // it down properly when using the IPC-based PPAPI proxy.
- // TODO(bbudge) Remove this when the proxy switch is complete.
- scoped_ptr< ::ppapi::PPP_Instance_Combined> nacl_plugin_instance_interface_;
+ // If this is the NaCl plugin, we create a new module when we switch to the
+ // IPC-based PPAPI proxy. Store the original module and instance interface
+ // so we can shut down properly.
+ scoped_refptr<PluginModule> nacl_module_;
+ scoped_ptr< ::ppapi::PPP_Instance_Combined> nacl_instance_interface_;
dmichael (off chromium) 2012/09/04 21:21:33 I feel like nacl_instance_interface_ is just as am
bbudge 2012/09/05 19:15:48 Done. How about original_module_ and original_inst
PP_Instance pp_instance_;

Powered by Google App Engine
This is Rietveld 408576698